************
Nengo extras
************

Extra utilities and add-ons for Nengo.

This repository contains utilities that occupy
a liminal space not quite generic enough for inclusion in Nengo_,
but useful enough that they should be publicly accessible.

Some of these utilities may eventually migrate to `Nengo core <Nengo>`_,
and others may be split off into their own separate repositories.
If something that you were using has been moved,
please consult the release history below
to see where it has been moved.

.. _Nengo: https://github.com/nengo/nengo

Installation
============

To install Nengo extras, we recommend using ``pip``.

.. code:: bash

   pip install nengo-extras

.. toctree::
   :maxdepth: 2

   deeplearning
   dists
   learning_rules
   networks
   neurons
   vision
   visualization

* :ref:`genindex`

.. include:: ../CHANGES.rst
